Stan Math Library: stan/math/prim/mat/err/constraint_tolerance.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Variables
constraint_tolerance.hpp File Reference

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Variables
const double | stan::math::CONSTRAINT_TOLERANCE = 1E-8
| The tolerance for checking arithmetic bounds In rank and in simplexes. More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.